@@ -48,6 +48,7 @@ def SetAlarm():
         print "* Alarm will go off on:",  time.ctime(event.trigger)
     else:
         print "Can not set alarm, Maemo interface not available"
+        data.AlarmID=1
         
     data.AlarmIsActive=False
 
@@ -64,13 +65,18 @@ def DeleteAlarm():
             try:
                 event = alarm.get_event(data.AlarmID) #get data of to be deleted alarm
                 alarm.delete_event(data.AlarmID)
+                
                 print "* Delete old Alarm:",  time.ctime(event.trigger)
             except:
-                pass
-            data.AlarmID=-1
+                pass            
         else:
             print "Can not delete alarm, Maemo interface not available"
-            
+        
+        data.AlarmID=-1
+        
+        if(data.AlarmIsActive==False): #if alarm never came, remove from record
+            records.AlarmTime_seconds=-1
+            records.AlarmTime_tuple=-1
     else:
         print "* No alarm to be deleted"        
 
