@@ -22,47 +22,48 @@ def LoadConfig():
     global config
     print "Configuration file:",  data.configfolder+data.ConfigFile
     config = ConfigParser.SafeConfigParser()
-    try:
-        config.read(data.configfolder+data.ConfigFile)
+#    try:
+    config.read(data.configfolder+data.ConfigFile)
+    
+    data.Sampling_interval = config.getint('main', 'sampling')
+    data.sample_smoothing = config.getint('main', 'sample_smoothing')
+    data.Value_smoothing = config.getint('main', 'value_smoothing')
+    data.Trigger = config.getint('main', 'Trigger')
+    data.Derivation = config.getint('main', 'Derivation')
+    data.Ysize = config.getint('main', 'Ysize')
+    data.Xscale = config.getint('main', 'Xscale')
+    data.Yscale = config.getint('main', 'Yscale')
+    u=config.get('main', 'user')
+    data.user = u.decode("utf-8") 
+    data.lastlogfile = config.get('main', 'lastlogfile')
+    data.OfflineMode = config.get('main', 'OfflineMode')
+    data.DelayStartTime = config.getint('main', 'DelayStartTime')
+    data.AlarmHour = config.getint('main', 'AlarmHour')
+    data.AlarmMinute = config.getint('main', 'AlarmMinute')
+    data.AlarmTimeWindow = config.getint('main', 'AlarmTimeWindow')
+    print "Configuration loaded ("+data.ConfigFile+")"
         
-        data.Sampling_interval = config.getint('main', 'sampling')
-        data.sample_smoothing = config.getint('main', 'sample_smoothing')
-        data.Value_smoothing = config.getint('main', 'value_smoothing')
-        data.Trigger = config.getint('main', 'Trigger')
-        data.Derivation = config.getint('main', 'Derivation')
-        data.Ysize = config.getint('main', 'Ysize')
-        data.Xscale = config.getint('main', 'Xscale')
-        data.Yscale = config.getint('main', 'Yscale')
-        data.user = config.get('main', 'user')
-        data.lastlogfile = config.get('main', 'lastlogfile')
-        data.OfflineMode = config.get('main', 'OfflineMode')
-        data.DelayStartTime = config.getint('main', 'DelayStartTime')
-        data.AlarmHour = config.getint('main', 'AlarmHour')
-        data.AlarmMinute = config.getint('main', 'AlarmMinute')
-        data.AlarmTimeWindow = config.getint('main', 'AlarmTimeWindow')
-        print "Configuration loaded ("+data.ConfigFile+")"
-        
-    except: #use default config
-        print data.configfolder+data.ConfigFile + " not existing or not read properly, using default parameters..."
-        try:
-            config.add_section('main')
-        except:
-            pass
-        config.set('main', 'sampling', str(data.Sampling_interval))
-        config.set('main', 'sample_smoothing', str(data.sample_smoothing))      
-        config.set('main', 'value_smoothing', str(data.Value_smoothing))      
-        config.set('main', 'Trigger', str(data.Trigger))      
-        config.set('main', 'Derivation', str(data.Derivation))      
-        config.set('main', 'Ysize', str(data.Ysize))      
-        config.set('main', 'Xscale', str(data.Xscale))     
-        config.set('main', 'Yscale', str(data.Yscale))      
-        config.set('main', 'user', str(data.user))      
-        config.set('main', 'lastlogfile', str(data.lastlogfile))    
-        config.set('main', 'OfflineMode', str(data.OfflineMode))      
-        config.set('main', 'DelayStartTime', str(data.DelayStartTime))    
-        config.set('main', 'AlarmHour', str(data.AlarmHour))    
-        config.set('main', 'AlarmMinute', str(data.AlarmMinute))    
-        config.set('main', 'AlarmTimeWindow', str(data.AlarmTimeWindow))    
+#    except: #use default config
+#        print data.configfolder+data.ConfigFile + " not existing or not read properly, using default parameters..."
+#        try:
+#            config.add_section('main')
+#        except:
+#            pass
+#        config.set('main', 'sampling', str(data.Sampling_interval))
+#        config.set('main', 'sample_smoothing', str(data.sample_smoothing))      
+#        config.set('main', 'value_smoothing', str(data.Value_smoothing))      
+#        config.set('main', 'Trigger', str(data.Trigger))      
+#        config.set('main', 'Derivation', str(data.Derivation))      
+#        config.set('main', 'Ysize', str(data.Ysize))      
+#        config.set('main', 'Xscale', str(data.Xscale))     
+#        config.set('main', 'Yscale', str(data.Yscale))      
+#        config.set('main', 'user', str(data.user.encode( "utf-8" )))      
+#        config.set('main', 'lastlogfile', str(data.lastlogfile))    
+#        config.set('main', 'OfflineMode', str(data.OfflineMode))      
+#        config.set('main', 'DelayStartTime', str(data.DelayStartTime))    
+#        config.set('main', 'AlarmHour', str(data.AlarmHour))    
+#        config.set('main', 'AlarmMinute', str(data.AlarmMinute))    
+#        config.set('main', 'AlarmTimeWindow', str(data.AlarmTimeWindow))    
 
     return config
 
