@@ -208,7 +208,7 @@ def showGraph(self,  QtGui):
     #DRAW main scaling lines + text        
     paint.setPen(QtGui.QColor("white"))
     if(data.QuickMode==False): #normal mode
-        print "OffsetToLastFullHour:",  OffsetToLastFullHour
+#        print "OffsetToLastFullHour:",  OffsetToLastFullHour
         if(data.Xscale==0): #max zoom
             for i in range(OffsetToLastFullHour-decade, 781+decade,  decade): #full hours
                 h=(h0+int(i/decade)+1) % 24
@@ -282,7 +282,7 @@ def showGraph(self,  QtGui):
                 paint.setBrush(QtGui.QColor(color))
                 paint.setPen(QtGui.QColor(color))
                 paint.drawRect(x0+1, data.Ysize-11, x1-x0-1, 10)                     
-#                paint.setPen(QtGui.QColor("yellow"))
+                paint.setPen(QtGui.QColor("yellow"))
 
 
 
@@ -302,10 +302,12 @@ def showGraph(self,  QtGui):
 #        x=i/Xscale+1
         paint.drawLine(x, data.Ysize-peak-1-15, x, data.Ysize-1-15)  #draw yellow movement bar
         
+        
         if(peak>data.Trigger):
             paint.setPen(QtGui.QColor("black"))
             paint.drawLine(x, data.Ysize-11, x, data.Ysize-1)  #draw yellow movement bar
             paint.setPen(QtGui.QColor("yellow"))
+#            print "Peak:", i,  x
 
 
 
@@ -386,6 +388,8 @@ def showGraph(self,  QtGui):
         paint.setPen(QtGui.QColor("Orange"))  
         x0=Tuple2Index(records.AlarmTimeWindowStart_tuple)-data.Derivation*Xscale
         x1=Tuple2Index(records.AlarmTimeWindowEnd_tuple)-data.Derivation*Xscale
+#        x0=Tuple2Index(records.AlarmTimeWindowStart_tuple)-data.Derivation
+#        x1=Tuple2Index(records.AlarmTimeWindowEnd_tuple)-data.Derivation
         x00=(x0-GraphStart_index)/Xscale
         x10=(x1-GraphStart_index)/Xscale
 #        if(x00>0 or x10<780): #visible in screen
@@ -401,12 +405,22 @@ def showGraph(self,  QtGui):
         paint.drawRect(x10,  4,  1,  10)  #Last Alarm opportunity
                 
         if(data.AlarmIsActive==True or data.run==0): #only show alarm if alarm occured or in record
-            paint.setBrush(QtGui.QColor("Red"))
-            paint.setPen(QtGui.QColor("Red"))  
-#            a0=Tuple2Index(records.AlarmTime_tuple)-data.Derivation-3+Xscale
-            a0=Tuple2Index(records.AlarmTime_tuple)-data.Derivation*Xscale
-            a00=(a0-GraphStart_index)/Xscale
-            paint.drawEllipse(a00-5, 15, 10, 10)     
+#            if(records.Index>=Tuple2Index(records.AlarmTimeWindowEnd_tuple)): #only show alarm dot when alarm really came
+            if(records.AlarmTime_seconds!=-1):
+                paint.setBrush(QtGui.QColor("Red"))
+                paint.setPen(QtGui.QColor("Red"))  
+#                print "AlarmTimeWindowEnd:",  records.AlarmTimeWindowEnd_seconds,  "AlarmTime:",  records.AlarmTime_seconds
+                if(records.AlarmTimeWindowEnd_seconds<=records.AlarmTime_seconds):
+#                    print "Alarm due end of alarm time window"
+                    a0=Tuple2Index(records.AlarmTime_tuple)-data.Derivation*Xscale
+                else:
+#                    print "alarm due movement"
+                    a0=Tuple2Index(records.AlarmTime_tuple)-data.Derivation
+                a00=(a0-GraphStart_index)/Xscale
+                paint.drawEllipse(a00-5, 15, 10, 10)     
+    #            print "AlarmTimeWindow:",  x1,  x10,  "Alarm:",  a0,  a00
+#            else:
+#                print "Alarm set, but never occured"
 
 
 
