@@ -127,8 +127,8 @@ def EditUserName():
      "It will be used in the records file, this makes it easier\n" + \
      "when you want to share your sleep pattern with others.", 0,  data.user)
     if(text != ""):
-        data.user=text[0]
-        config.set('main', 'user', str(data.user))    
+        data.user=unicode(text[0])
+        config.set('main', 'user', str(data.user.encode( "utf-8" )))    
     else:
         pass
     print "User name:",  data.user
@@ -235,13 +235,16 @@ def InitMeasurement():
 
 def StopMeasurement():
     global app
+    
+    DeleteAlarm() #delete Alarm if existing
+    
     if(data.run==2): #in recording
         app.timer_GetData.stop()
         StopLogfile() 
         UpdateFileHeader() #rewrite log file (only do when recording is stopped!)
 
     data.run=0
-    DeleteAlarm() #delete Alarm if existing
+
     
     if(data.QuickMode==False): #normal mode
         if(data.OfflineMode=="True" and data.demo!=1): #change to offline mode
@@ -609,8 +612,8 @@ class frmRecordWindow(QMainWindow):
     def EditNote(self):
         r=QInputDialog.getText(None,  "Add Note",  "Add a note to this record:\n(leave empty for no note)",  QLineEdit.Normal,  records.Note)
         if(r[1]==True): #OK pressed
-            records.Note=str(r[0])
-            self.ui.lblNote.setText(str(records.Note))
+            records.Note=unicode(r[0])
+            self.ui.lblNote.setText(records.Note)
             if(data.run==0): UpdateFileHeader() #rewrite log file (only do when recording is stopped!)
 
 
@@ -684,15 +687,19 @@ class frmViewWindow(QMainWindow):
             d1=strftime("%X", EndTime_tuple) #on same day, only show date once
         else:
             d1=strftime("%a. %x %X", EndTime_tuple) 
-            
-        diff_sec=records.Index*records.Sampling_interval*records.Value_smoothing/1000
-        diff_tuple=Seconds2Tuple(diff_sec)
-        diff=strftime("%H:%M:%S", diff_tuple)
+#            
+#        diff_sec=records.Index*records.Sampling_interval*records.Value_smoothing/1000
+        diff_sec=Tuple2Seconds(EndTime_tuple)-Tuple2Seconds(records.StartTime_tuple)
+#        print diff_sec,  Tuple2Seconds(EndTime_tuple), Tuple2Seconds(records.StartTime_tuple)
+#        diff_tuple=Seconds2Tuple(diff_sec)
+#        print diff_tuple,  records.StartTime_tuple,  EndTime_tuple
+#        diff=strftime("%H:%M:%S", diff_tuple)
+        diff=time.strftime("%X", time.gmtime(diff_sec))
         if(diff_sec>86400): d="1 day, " #longer than 24h
         else: d=""
         self.ui.lblTimes.setText(str(d0)+"  -  "+str(d1)+"  (Duration: "+d+str(diff)+")")
 
-        self.ui.lblNote.setText(str(records.Note))
+        self.ui.lblNote.setText(records.Note)
 
         if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
         else: self.ui.bZoomIn.setEnabled(True)
@@ -894,8 +901,10 @@ class frmViewWindow(QMainWindow):
     def EditNote(self):
         r=QInputDialog.getText(None,  "Edit Note",  "Add a note to this record:\n(leave empty for no note)",  QLineEdit.Normal,  records.Note)
         if(r[1]==True): #OK pressed
-            records.Note=str(r[0])
-            self.ui.lblNote.setText(str(records.Note))
+            tmp=r[0]
+            tmp=unicode(tmp)
+            records.Note=tmp
+            self.ui.lblNote.setText(records.Note)
             UpdateFileHeader() #rewrite log file (only do when recording is stopped!)
 
 
@@ -930,11 +939,12 @@ class frmViewWindow(QMainWindow):
         
         QtGui.QMessageBox.information(self, 'About this record', "File: "+str(data.logfilename+"\n") + \
         "Folder: "+str(shortfolder) +"\n" + \
+        "User: "+records.User +"\n" + \
         "Start: "+d0 + "\n" + \
         "End: "+d1 + "\n" + \
         "Duration: "+diff + ", " + \
         "Total "+str(records.Index)+" entries\n" +\
-        "Note: "+str(records.Note)+"\n" +\
+        "Note: "+records.Note+"\n" +\
         alarm +\
         "Condition of record: "+str(records.status)+"\n" + \
         "Sampling interval: "+str(records.Sampling_interval) + ", " + \
@@ -971,7 +981,7 @@ class frmConfigWindow(QMainWindow):
     def UpdateScreen(self):
         if(data.OfflineMode=="True"): self.ui.cOfflineMode.setChecked(True)
         else: self.ui.cOfflineMode.setChecked(False)        
-        self.ui.lblUserName.setText(str(data.user))
+        self.ui.lblUserName.setText(data.user)
         self.ui.lblDelayStart.setText(str(data.DelayStartTime)+" sec")
         self.ui.SlrDelayStart.setValue(int(data.DelayStartTime))
 
@@ -982,7 +992,7 @@ class frmConfigWindow(QMainWindow):
         else: 
             data.OfflineMode="False"
         config.set('main', 'OfflineMode', str(data.OfflineMode))   
-        config.set('main', 'user', str(data.user))      
+        config.set('main', 'user', str(data.user.encode( "utf-8" )))      
         config.set('main', 'DelayStartTime', str(data.DelayStartTime))      
         
         ConfigWindow.close()
@@ -991,7 +1001,7 @@ class frmConfigWindow(QMainWindow):
 
     def EditUserName(self):
         EditUserName()
-        self.ui.lblUserName.setText(str(data.user))
+        self.ui.lblUserName.setText(data.user)
         
         
     def SliderMoved(self):
@@ -1221,8 +1231,8 @@ class frmAskForKeepWindow(QMainWindow):
     def RemoveRecord(self): #removed record
         print "Stop recording and remove record"
         global StartWindow,  RecordWindow
-        StopMeasurement()
         DeleteAlarm() #delete Alarm if existing
+        StopMeasurement()
         records.AlarmIsSet=False
         print "Delete logfile: "+data.logfilename
         os.remove(data.logfolder+data.logfilename)
